import 'dart:async';

import 'package:shared_preferences/shared_preferences.dart';

const String _storageKey = "Language_";
const String _kDefaultLanguage = "en";

Future<SharedPreferences> _prefsLanguage = SharedPreferences.getInstance();

LanguagePreferences languagePreferences = LanguagePreferences();

class LanguagePreferences {
  /// ----------------------------------------------------------
  /// Generic routine to fetch a preference
  /// ----------------------------------------------------------
  Future<String> _getApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefsLanguage;

    return prefs.getString(_storageKey + name) ?? '';
  }

  /// ----------------------------------------------------------
  /// Generic routine to saves a preference
  /// ----------------------------------------------------------
  Future<bool> _setApplicationSavedInformation(
      String name, String value) async {
    final SharedPreferences prefs = await _prefsLanguage;

    return prefs.setString(_storageKey + name, value);
  }

  /// ----------------------------------------------------------
  /// Method that saves/restores the preferred language
  /// ----------------------------------------------------------
  Future<String> getPreferredLanguage() async {
    return _getApplicationSavedInformation('language');
  }

  Future<bool> setPreferredLanguage(String lang) async {
    return _setApplicationSavedInformation('language', lang);
  }

  String get defaultLanguage => _kDefaultLanguage;

  // ------------------ SINGLETON -----------------------
  static final LanguagePreferences _preferences =
      LanguagePreferences._internal();

  factory LanguagePreferences() {
    return _preferences;
  }

  LanguagePreferences._internal();
}
