import 'package:flutter/material.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/colors.dart';
import 'package:hqsoft_core/value_base/value_base.dart';

class CustomCalendarFilterView extends StatefulWidget {
  final DateTime minimumDate;
  final DateTime maximumDate;
  final DateTime initialSelectDate;

//  final DateTime initialEndDate;
  final Function(DateTime) startEndDateChange;

  const CustomCalendarFilterView(
      {Key key,
      this.initialSelectDate,
//      this.initialEndDate,
      this.startEndDateChange,
      this.minimumDate,
      this.maximumDate})
      : super(key: key);

  @override
  _CustomCalendarFilterViewState createState() =>
      _CustomCalendarFilterViewState();
}

class _CustomCalendarFilterViewState extends State<CustomCalendarFilterView> {
  List<DateTime> dateList = List<DateTime>();
  List<String> dateNameList = [
    allTranslations.text("sys_mon"),
    allTranslations.text("sys_tue"),
    allTranslations.text("sys_wed"),
    allTranslations.text("sys_thu"),
    allTranslations.text("sys_fri"),
    allTranslations.text("sys_sat"),
    allTranslations.text("sys_sun"),
  ];
  var currentMonthDate = DateTime.now();
  DateTime selectDate;

//  DateTime endDate;

  @override
  void initState() {
    _setListOfDate(currentMonthDate);
    if (widget.initialSelectDate != null) {
      selectDate = widget.initialSelectDate;
    }
//    if (widget.initialEndDate != null) {
//      endDate = widget.initialEndDate;
//    }
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  void _setListOfDate(DateTime monthDate) {
    dateList.clear();
    var newDate = DateTime(monthDate.year, monthDate.month, 0);
    int previousMothDay = 0;
    if (newDate.weekday < 7) {
      previousMothDay = newDate.weekday;
      for (var i = 1; i <= previousMothDay; i++) {
        dateList.add(newDate.subtract(Duration(days: previousMothDay - i)));
      }
    }
    for (var i = 0; i < (42 - previousMothDay); i++) {
      dateList.add(newDate.add(Duration(days: i + 1)));
    }
    // if (dateList[dateList.length - 7].month != monthDate.month) {
    //   dateList.removeRange(dateList.length - 7, dateList.length);
    // }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Column(
        children: <Widget>[
          Padding(
            padding: EdgeInsets.only(
                left: ScreenConfig.getWidthPx(8),
                right: ScreenConfig.getWidthPx(8),
                top: ScreenConfig.getWidthPx(0),
                bottom: ScreenConfig.getWidthPx(4)),
            child: Row(
              children: <Widget>[
                Padding(
                  padding: EdgeInsets.only(
                      left: ScreenConfig.getWidthPx(8),
                      right: ScreenConfig.getWidthPx(8),
                      top: ScreenConfig.getWidthPx(2),
                      bottom: ScreenConfig.getWidthPx(4)),
                  child: Container(
                    height: ScreenConfig.getWidthPx(25),
                    width: ScreenConfig.getWidthPx(25),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.all(Radius.circular(24.0)),
                      border: new Border.all(
                        color: colorPrimary,
                      ),
                    ),
                    child: Material(
                      color: Colors.transparent,
                      child: InkWell(
                        borderRadius: BorderRadius.all(Radius.circular(24.0)),
                        onTap: () {
                          setState(() {
                            currentMonthDate = DateTime(currentMonthDate.year,
                                currentMonthDate.month, 0);
                            _setListOfDate(currentMonthDate);
                          });
                        },
                        child: Icon(
                          Icons.keyboard_arrow_left,
                          color: Colors.grey,
                        ),
                      ),
                    ),
                  ),
                ),
                Expanded(
                  child: Center(
                    child: Text(
                        allTranslations.text("sys_month") +
                            DateHelper.getStringJsonFormat(
                                currentMonthDate, " MM, yyyy"),
                        //DateFormat("MMMM, yyyy").format(currentMonthDate),
                        style: ThemeBase.textBlackBoldFontSize14),
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(
                      left: ScreenConfig.getWidthPx(8),
                      right: ScreenConfig.getWidthPx(8),
                      top: ScreenConfig.getWidthPx(0),
                      bottom: ScreenConfig.getWidthPx(4)),
                  child: Container(
                    height: ScreenConfig.getWidthPx(25),
                    width: ScreenConfig.getWidthPx(25),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.all(Radius.circular(24.0)),
                      border: new Border.all(
                        color: colorPrimary,
                      ),
                    ),
                    child: Material(
                      color: Colors.transparent,
                      child: InkWell(
                        borderRadius: BorderRadius.all(Radius.circular(24.0)),
                        onTap: () {
                          setState(() {
                            currentMonthDate = DateTime(currentMonthDate.year,
                                currentMonthDate.month + 2, 0);
                            _setListOfDate(currentMonthDate);
                          });
                        },
                        child: Icon(
                          Icons.keyboard_arrow_right,
                          color: Colors.grey,
                        ),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(right: 4, left: 4, bottom: 4),
            child: Row(
              children: _getDaysNameUI(),
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(right: 4, left: 4),
            child: Column(
              children: _getDaysNoUI(),
            ),
          ),
        ],
      ),
    );
  }

  List<Widget> _getDaysNameUI() {
    List<Widget> listUI = List<Widget>();
    for (var i = 0; i < 7; i++) {
      listUI.add(
        Expanded(
          child: Center(
            child: Text(
                dateNameList[i]
                    .toString(), //DateFormat("EEE").format(dateNameList[i]),
                style: ThemeBase.textColorPrimaryFontSize14),
          ),
        ),
      );
    }
    return listUI;
  }

  List<Widget> _getDaysNoUI() {
    List<Widget> noList = List<Widget>();
    var count = 0;
    for (var i = 0; i < dateList.length / 7; i++) {
      List<Widget> listUI = List<Widget>();
      for (var i = 0; i < 7; i++) {
        final date = dateList[count];
        listUI.add(
          Expanded(
            child: AspectRatio(
              aspectRatio: 1.5,
              child: Container(
                child: Stack(
                  children: <Widget>[
                    Padding(
                      padding: const EdgeInsets.only(top: 3, bottom: 3),
                      child: Material(
                        color: Colors.transparent,
                        child: Padding(
                          padding: EdgeInsets.only(
                              top: ScreenConfig.getWidthPx(2),
                              bottom: ScreenConfig.getWidthPx(2),
                              left: _isStartDateRadius(date)
                                  ? ScreenConfig.getWidthPx(4)
                                  : 0,
                              right: _isStartDateRadius(date)
                                  ? ScreenConfig.getWidthPx(4)
                                  : 0),
                          child: Container(
                            decoration: BoxDecoration(
                              color: selectDate != null
                                  ? _getIsItStartAndEndDate(date)
                                      ? colorPrimary.withOpacity(0.4)
                                      : Colors.transparent
                                  : Colors.transparent,
                              borderRadius: BorderRadius.only(
                                bottomLeft: _isStartDateRadius(date)
                                    ? Radius.circular(12.0)
                                    : Radius.circular(0.0),
                                topLeft: _isStartDateRadius(date)
                                    ? Radius.circular(12.0)
                                    : Radius.circular(0.0),
                                topRight: _isStartDateRadius(date)
                                    ? Radius.circular(12.0)
                                    : Radius.circular(0.0),
                                bottomRight: _isStartDateRadius(date)
                                    ? Radius.circular(12.0)
                                    : Radius.circular(0.0),
                              ),
                            ),
                          ),
                        ),
                      ),
                    ),
                    Material(
                      color: Colors.transparent,
                      child: InkWell(
                        borderRadius: BorderRadius.all(Radius.circular(32.0)),
                        onTap: () {
                          if (currentMonthDate.month == date.month) {
                            _onDateClick(date);
                          }

//                            if (currentMonthDate.month == date.month) {
//                              if (widget.minimumDate != null &&
//                                  widget.maximumDate != null) {
//
//                                var newminimumDate = DateTime(
//                                    widget.minimumDate.year,
//                                    widget.minimumDate.month,
//                                    widget.minimumDate.day - 1);
//
//                                var newmaximumDate = DateTime(
//                                    widget.maximumDate.year,
//                                    widget.maximumDate.month,
//                                    widget.maximumDate.day + 1);
//                                if (date.isAfter(newminimumDate) &&
//                                    date.isBefore(newmaximumDate)) {
//                                  onDateClick(date);
//                                }
//
//
//                              } else if (widget.minimumDate != null) {
//
//                                var newminimumDate = DateTime(
//                                    widget.minimumDate.year,
//                                    widget.minimumDate.month,
//                                    widget.minimumDate.day +1);
//                                if (date.isBefore(newminimumDate)) {
//                                  onDateClick(date);
//                                }
//
//                              } else if (widget.maximumDate != null) {
//
//                                var newmaximumDate = DateTime(
//                                    widget.maximumDate.year,
//                                    widget.maximumDate.month,
//                                    widget.maximumDate.day + 1);
//                                if (date.isAfter(newmaximumDate)) {
//                                  onDateClick(date);
//                                }
//
//                              } else {
//
//                                onDateClick(date);
//                              }
//                          }
                        },
                        child: Padding(
                          padding: EdgeInsets.all(2),
                          child: Container(
                            decoration: BoxDecoration(
                              color: _getIsItStartAndEndDate(date)
                                  ? colorPrimary
                                  : Colors.transparent,
                              borderRadius:
                                  BorderRadius.all(Radius.circular(32.0)),
                              border: Border.all(
                                color: _getIsItStartAndEndDate(date)
                                    ? Colors.white
                                    : Colors.transparent,
                                width: 2,
                              ),
                              boxShadow: _getIsItStartAndEndDate(date)
                                  ? <BoxShadow>[
                                      BoxShadow(
                                          color: Colors.grey.withOpacity(0.6),
                                          blurRadius: 4,
                                          offset: Offset(0, 0)),
                                    ]
                                  : null,
                            ),
                            child: Center(
                              child: Text(
                                "${date.day}",
                                style: TextStyle(
                                    color: _getIsItStartAndEndDate(date)
                                        ? Colors.white
                                        : currentMonthDate.month == date.month
                                            ? Colors.black
                                            : Colors.grey.withOpacity(0.6),
                                    fontSize:
                                        MediaQuery.of(context).size.width > 360
                                            ? 14
                                            : 13,
                                    fontWeight: _getIsItStartAndEndDate(date)
                                        ? FontWeight.bold
                                        : FontWeight.normal),
                              ),
                            ),
                          ),
                        ),
                      ),
                    ),
//                    Positioned(
//                      bottom: ScreenConfig.getWidthPx(5),
//                      right: 0,
//                      left: 0,
//                      child: Container(
//                        height: ScreenConfig.getWidthPx(4),
//                        width: ScreenConfig.getWidthPx(4),
//                        decoration: BoxDecoration(
//                            color: DateTime.now().day == date.day &&
//                                    DateTime.now().month == date.month &&
//                                    DateTime.now().year == date.year ? Colors.white:colorRed,
//                            shape: BoxShape.circle),
//                      ),
//                    ),
                  ],
                ),
              ),
            ),
          ),
        );
        count += 1;
      }
      noList.add(Row(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisSize: MainAxisSize.min,
        children: listUI,
      ));
    }
    return noList;
  }

//  bool getIsInRange(DateTime date) {
//    if (startDate != null && endDate != null) {
//      if (date.isAfter(startDate) && date.isBefore(endDate)) {
//        return true;
//      } else {
//        return false;
//      }
//    } else {
//      return false;
//    }
//  }

  bool _getIsItStartAndEndDate(DateTime date) {
    if (selectDate != null &&
        selectDate.day == date.day &&
        selectDate.month == date.month &&
        selectDate.year == date.year) {
      return true;
    } else {
      return false;
    }
  }

  bool _isStartDateRadius(DateTime date) {
    if (selectDate != null &&
        selectDate.day == date.day &&
        selectDate.month == date.month) {
      return true;
    } else if (date.weekday == 1) {
      return true;
    } else {
      return false;
    }
  }

  void _onDateClick(DateTime date) {
//    if (startDate == null) {
//      startDate = date;
//    } else if (startDate != date && endDate == null) {
//      endDate = date;
//    } else if (startDate.day == date.day && startDate.month == date.month) {
//      startDate = null;
//    } else if (endDate.day == date.day && endDate.month == date.month) {
//      endDate = null;
//    }
//    if (startDate == null && endDate != null) {
//      startDate = endDate;
//      endDate = null;
//    }
//    if (startDate != null && endDate != null) {
//      if (!endDate.isAfter(startDate)) {
//        var d = startDate;
//        startDate = endDate;
//        endDate = d;
//      }
//      if (date.isBefore(startDate)) {
//        startDate = date;
//      }
//      if (date.isAfter(endDate)) {
//        endDate = date;
//      }
//    }
    selectDate = date;
    setState(() {
      try {
        widget.startEndDateChange(selectDate);
      } catch (e) {}
    });
  }
}
